pub struct CapturedProcedure {
pub id: String,
pub title: String,
pub description: String,
pub steps: Vec<ProcedureStep>,
pub confidence: ProcedureConfidence,
pub tags: Vec<String>,
pub created_at: String,
pub updated_at: String,
pub source_session: Option<String>,
pub disabled: bool,
}Expand description
A captured procedure with ordered steps and execution history.
Fields
id: StringUnique identifier (UUID)
title: StringHuman-readable title
description: StringDescription of what this procedure does
steps: Vec<ProcedureStep>Ordered steps to execute
confidence: ProcedureConfidenceConfidence metrics
Tags for categorization
created_at: StringCreation timestamp (ISO 8601)
updated_at: StringLast update timestamp (ISO 8601)
source_session: Option<String>Source session ID if captured from a session
disabled: boolWhether this procedure has been disabled (e.g., by auto-healing)
Implementations
Sourceimpl CapturedProcedure
impl CapturedProcedure
Sourcepub fn new(id: String, title: String, description: String) -> CapturedProcedure
pub fn new(id: String, title: String, description: String) -> CapturedProcedure
Create a new captured procedure.
Sourcepub fn add_step(&mut self, step: ProcedureStep)
pub fn add_step(&mut self, step: ProcedureStep)
Add a step to the procedure.
Sourcepub fn add_steps(&mut self, steps: Vec<ProcedureStep>)
pub fn add_steps(&mut self, steps: Vec<ProcedureStep>)
Add multiple steps to the procedure.
Sourcepub fn with_source_session(self, session_id: String) -> CapturedProcedure
pub fn with_source_session(self, session_id: String) -> CapturedProcedure
Set the source session ID.
Add tags.
Sourcepub fn with_confidence(
self,
confidence: ProcedureConfidence,
) -> CapturedProcedure
pub fn with_confidence( self, confidence: ProcedureConfidence, ) -> CapturedProcedure
Set the confidence metrics.
Sourcepub fn record_success(&mut self)
pub fn record_success(&mut self)
Record a successful execution.
Sourcepub fn record_failure(&mut self)
pub fn record_failure(&mut self)
Record a failed execution.
Sourcepub fn step_count(&self) -> usize
pub fn step_count(&self) -> usize
Get the number of steps.
Sourcepub fn merge_steps(&mut self, other: &CapturedProcedure)
pub fn merge_steps(&mut self, other: &CapturedProcedure)
Merge steps from another procedure into this one.
This is used for deduplication - when a similar procedure is found, we can merge the steps to consolidate knowledge.