pub struct Priority(pub u8);Expand description
Priority level for routing rules and decisions Higher numeric values indicate higher priority A clamped priority value in the range 0–100 (higher = more urgent).
Tuple Fields
0: u8Implementations